MemoryFetcher

Struct MemoryFetcher 

pub struct MemoryFetcher { /* private fields */ }
In-memory fetcher useful for tests and fixtures.

Implementations

Source

impl MemoryFetcher

pub fn new() -> Self

Creates an empty memory fetcher.

pub fn insert(&mut self, url: IndexUrl, body: impl Into<String>)

Registers a response body for a URL.

pub fn insert_response(&mut self, requested_url: IndexUrl, response: Response)

Registers a complete response for a URL.

pub fn insert_error(&mut self, url: IndexUrl, error: FetchError)

Registers a deterministic fetch error for a URL.

pub fn insert_form_response( &mut self, submission: &FormSubmission, response: Response, )

Registers a complete response for a resolved form submission.

pub fn insert_form_error( &mut self, submission: &FormSubmission, error: FetchError, )

Registers a deterministic form submission error.

pub fn insert_redirect( &mut self, requested_url: IndexUrl, final_url: IndexUrl, redirects: Vec<IndexUrl>, body: impl Into<String>, )

Registers a response that ended at a different URL.